@@ -57,6 +57,10 @@ def features_0D(data, marker='o', cmap='bwr', color=None, configs=None, **kwargs
             'save':  dict(),
             }
         configs = configs or {}
+        for key in configs:
+            if key not in defaults:
+                raise ValueError(f"unexpected `configs` key: {key}; "
+                                 "supported are: %s" % ', '.join(list(defaults)))
         # override defaults, but keep those not in `configs`
         for key in defaults:
             defaults[key].update(configs.get(key, {}))
@@ -119,7 +123,7 @@ def features_0D(data, marker='o', cmap='bwr', color=None, configs=None, **kwargs
     return fig, axes
 
 
-def features_1D(data, n_rows=None, annotations='auto', equate_axes=True,
+def features_1D(data, n_rows=None, annotations='auto', share_xy=(1, 1),
                 max_timesteps=None, subplot_samples=False, configs=None,
                 **kwargs):
     """Plots 1D curves in a standalone graph or subplot grid.
@@ -136,7 +140,14 @@ def features_1D(data, n_rows=None, annotations='auto', equate_axes=True,
              list of str: annotate by indexing into the list.
                           If len(list) < len(data), won't annotate remainder.
              None: don't annotate.
-        equate_axes:    bool. If True, subplots will share x- and y-axes limits.
+        share_xy: bool/str/(tuple/list of bool/str) for (sharex, sharey)
+              kwargs passed to plt.subplots(). If bool/str, will use same
+              value for sharex & sharey.
+              - sharex: bool/str. True  -> subplots will share x-axes limits.
+                                  'col' -> limits shared along columns.
+                                  'row' -> limits shared along rows.
+                                  Overrides 'sharex' in `configs['subplot']`.
+              - sharey: bool/str. `sharex`, but for y-axis.
         max_timesteps:  int/None. Max number of timesteps to show per plot.
               If None, keeps original.
         subplot_samples: bool. If True, generates a subplot per dim 0 of `data`
@@ -185,10 +196,22 @@ def features_1D(data, n_rows=None, annotations='auto', equate_axes=True,
     color         = kwargs.get('color', None)
     savepath      = kwargs.get('savepath', None)
 
-    def _process_configs(configs, w, h, tight, equate_axes):
+    def _process_configs(configs, w, h, tight, share_xy):
+        def _set_share_xy(kw, share_xy):
+            if isinstance(share_xy, (list, tuple)):
+                sharex, sharey = share_xy
+            else:
+                sharex = sharey = share_xy
+            if isinstance(sharex, int):
+                sharex = bool(sharex)
+            if isinstance(sharey, int):
+                sharey = bool(sharey)
+            kw['subplot']['sharex'] = sharex
+            kw['subplot']['sharey'] = sharey
+
         defaults = {
             'plot':    dict(),
-            'subplot': dict(sharex=True, sharey=True, dpi=76, figsize=(10, 10)),
+            'subplot': dict(dpi=76, figsize=(10, 10)),
             'title':   dict(weight='bold', fontsize=14, y=.93 + .12 * tight),
             'tight':   dict(left=0, right=1, bottom=0, top=1, wspace=0, hspace=0),
             'annot':   dict(weight='bold', fontsize=16, color='g',
@@ -196,13 +219,16 @@ def features_1D(data, n_rows=None, annotations='auto', equate_axes=True,
             'save':    dict(),
             }
         configs = configs or {}
+        for key in configs:
+            if key not in defaults:
+                raise ValueError(f"unexpected `configs` key: {key}; "
+                                 "supported are: %s" % ', '.join(list(defaults)))
         # override defaults, but keep those not in `configs`
         for key in defaults:
             defaults[key].update(configs.get(key, {}))
         kw = defaults.copy()
 
-        if not equate_axes:
-            kw['subplot'].update({'sharex': False, 'sharey': False})
+        _set_share_xy(kw, share_xy)
         size = kw['subplot']['figsize']
         kw['subplot']['figsize'] = (size[0] * w, size[1] * h)
         return kw
@@ -278,7 +304,7 @@ def features_1D(data, n_rows=None, annotations='auto', equate_axes=True,
         if not show_borders:
             ax.set_frame_on(False)
 
-    kw = _process_configs(configs, w, h, tight, equate_axes)
+    kw = _process_configs(configs, w, h, tight, share_xy)
     _catch_unknown_kwargs(kwargs)
     data = _process_data(data)
     n_rows, n_cols, color, annotations = _get_style_info(data, n_rows, color,
@@ -314,7 +340,8 @@ def features_1D(data, n_rows=None, annotations='auto', equate_axes=True,
 
 
 def features_2D(data, n_rows=None, norm=None, cmap='bwr', reflect_half=False,
-                timesteps_xaxis=True, max_timesteps=None, configs=None, **kwargs):
+                timesteps_xaxis=True, max_timesteps=None, share_xy=(1, 1),
+                configs=None, **kwargs):
     """Plots 2D heatmaps in a standalone graph or subplot grid.
 
     iter == list/tuple (both work)
@@ -339,6 +366,14 @@ def features_2D(data, n_rows=None, norm=None, cmap='bwr', reflect_half=False,
               if plotted along the x-axis.
         max_timesteps:  int/None. Max number of timesteps to show per plot.
               If None, keeps original.
+        share_xy: bool/str/(tuple/list of bool/str) for (sharex, sharey)
+              kwargs passed to plt.subplots(). If bool/str, will use same
+              value for sharex & sharey.
+              - sharex: bool/str. True  -> subplots will share x-axes limits.
+                                  'col' -> limits shared along columns.
+                                  'row' -> limits shared along rows.
+                                  Overrides 'sharex' in `configs['subplot']`.
+              - sharey: bool/str. `sharex`, but for y-axis.
         configs: dict. kwargs to customize various plot schemes:
             'plot':     passed to fig.hist(); fig = subplots figure
             'subplot':  passed to plt.subplots()
@@ -381,21 +416,38 @@ def features_2D(data, n_rows=None, norm=None, cmap='bwr', reflect_half=False,
     borderwidth   = kwargs.get('borderwidth', None)
     savepath      = kwargs.get('savepath', None)
 
-    def _process_configs(configs, w, h, tight):
+    def _process_configs(configs, w, h, tight, share_xy):
+        def _set_share_xy(kw, share_xy):
+            if isinstance(share_xy, (list, tuple)):
+                sharex, sharey = share_xy
+            else:
+                sharex = sharey = share_xy
+            if isinstance(sharex, int):
+                sharex = bool(sharex)
+            if isinstance(sharey, int):
+                sharey = bool(sharey)
+            kw['subplot']['sharex'] = sharex
+            kw['subplot']['sharey'] = sharey
+
         defaults = {
             'plot':    dict(),
-            'subplot': dict(sharex=True, sharey=True, dpi=76, figsize=(10, 10)),
+            'subplot': dict(dpi=76, figsize=(10, 10)),
             'title':   dict(weight='bold', fontsize=14, y=.93 + .12 * tight),
             'tight':   dict(left=0, right=1, bottom=0, top=1, wspace=0, hspace=0),
             'colorbar': dict(),
             'save':     dict(),
             }
         configs = configs or {}
+        for key in configs:
+            if key not in defaults:
+                raise ValueError(f"unexpected `configs` key: {key}; "
+                                 "supported are: %s" % ', '.join(list(defaults)))
         # override defaults, but keep those not in `configs`
         for key in defaults:
             defaults[key].update(configs.get(key, {}))
         kw = defaults.copy()
 
+        _set_share_xy(kw, share_xy)
         size = kw['subplot']['figsize']
         kw['subplot']['figsize'] = (size[0] * w, size[1] * h)
         return kw
@@ -468,7 +520,7 @@ def features_2D(data, n_rows=None, norm=None, cmap='bwr', reflect_half=False,
             ax.set_frame_on(False)
 
     _catch_unknown_kwargs(kwargs)
-    kw = _process_configs(configs, w, h, tight)
+    kw = _process_configs(configs, w, h, tight, share_xy)
     data = _process_data(data, max_timesteps, reflect_half,
                          timesteps_xaxis, channel_axis)
     n_rows, n_cols, vmin, vmax = _get_style_info(data, n_rows, norm)
@@ -512,7 +564,8 @@ def _get_nrows_and_ncols(n_rows, n_subplots):
     return n_rows, n_cols
 
 
-def features_hist(data, n_rows='vertical', bins=100, xlims=None, tight=True,
+def features_hist(data, n_rows='vertical', bins=100, xlims=None,
+                  center_zero=False, tight=True, share_xy=('col', 1),
                   annotations='auto', configs=None, **kwargs):
     """Plots histograms in a subplot grid.
 
@@ -524,8 +577,18 @@ def features_hist(data, n_rows='vertical', bins=100, xlims=None, tight=True,
               If 'vertical', sets n_rows = len(data).
         bins: int. Pyplot kwarg to plt.hist(), # of bins.
         xlims: float tuple. x limits to apply to all subplots.
+        center_zero: bool. If True, symmetrize xlims: (-max, max).
+              Overrides `xlims`.
         tight: bool. If True, plt.subplots_adjust (spacing) according to
               configs['tight'], defaulted to minimize intermediate padding.
+        share_xy: bool/str/(tuple/list of bool/str) for (sharex, sharey)
+              kwargs passed to plt.subplots(). If bool/str, will use same
+              value for sharex & sharey.
+              - sharex: bool/str. True  -> subplots will share x-axes limits.
+                                  'col' -> limits shared along columns.
+                                  'row' -> limits shared along rows.
+                                  Overrides 'sharex' in `configs['subplot']`.
+              - sharey: bool/str. `sharex`, but for y-axis.
         annotations: str list/'auto'/None.
             'auto': annotate each subplot with its index.
              list of str: annotate by indexing into the list.
@@ -564,10 +627,22 @@ def features_hist(data, n_rows='vertical', bins=100, xlims=None, tight=True,
     borderwidth   = kwargs.get('borderwidth', None)
     savepath      = kwargs.get('savepath', None)
 
-    def _process_configs(configs, w, h, tight):
+    def _process_configs(configs, w, h, tight, share_xy):
+        def _set_share_xy(kw, share_xy):
+            if isinstance(share_xy, (list, tuple)):
+                sharex, sharey = share_xy
+            else:
+                sharex = sharey = share_xy
+            if isinstance(sharex, int):
+                sharex = bool(sharex)
+            if isinstance(sharey, int):
+                sharey = bool(sharey)
+            kw['subplot']['sharex'] = sharex
+            kw['subplot']['sharey'] = sharey
+
         defaults = {
             'plot':    dict(peaks_to_clip=0),
-            'subplot': dict(sharex='col', sharey=True, dpi=76, figsize=(10, 10)),
+            'subplot': dict(dpi=76, figsize=(10, 10)),
             'title':   dict(weight='bold', fontsize=14, y=.93 + .12 * tight),
             'tight':   dict(left=0, right=1, bottom=0, top=1, wspace=0, hspace=0),
             'annot':   dict(weight='bold', fontsize=14, xy=(.02, .7),
@@ -575,11 +650,16 @@ def features_hist(data, n_rows='vertical', bins=100, xlims=None, tight=True,
             'save': dict(),
             }
         configs = configs or {}
+        for key in configs:
+            if key not in defaults:
+                raise ValueError(f"unexpected `configs` key: {key}; "
+                                 "supported are: %s" % ', '.join(list(defaults)))
         # override defaults, but keep those not in `configs`
         for key in defaults:
             defaults[key].update(configs.get(key, {}))
         kw = defaults.copy()
 
+        _set_share_xy(kw, share_xy)
         size = kw['subplot']['figsize']
         kw['subplot']['figsize'] = (size[0] * w, size[1] * h)
         return kw
@@ -605,7 +685,8 @@ def features_hist(data, n_rows='vertical', bins=100, xlims=None, tight=True,
             annotations = annotations.copy()
         return n_rows, n_cols, annotations
 
-    def _style_axis(ax, kw, show_borders, show_xy_ticks, xlims, annotations):
+    def _style_axis(ax, kw, show_borders, show_xy_ticks, xlims,
+                    center_zero, annotations):
         if not show_xy_ticks[0]:
             ax.set_xticks([])
         if not show_xy_ticks[1]:
@@ -614,12 +695,17 @@ def features_hist(data, n_rows='vertical', bins=100, xlims=None, tight=True,
             ax.annotate(annotations.pop(0), **kw['annot'])
         if not show_borders:
             ax.set_frame_on(False)
-        if xlims is not None:
+        if center_zero:
+            maxlim = max(np.abs(ax.get_xlim()))
+            ax.set_xlim(-maxlim, maxlim)
+        elif xlims is not None:
             ax.set_xlim(*xlims)
 
     _catch_unknown_kwargs(kwargs)
-    kw = _process_configs(configs, w, h, tight)
+    kw = _process_configs(configs, w, h, tight, share_xy)
     n_rows, n_cols, annotations = _get_style_info(data, n_rows, annotations)
+    if center_zero and xlims is not None:
+        print(NOTE, "`center_zero` will override `xlims`")
 
     fig, axes = plt.subplots(n_rows, n_cols, **kw['subplot'])
     if n_cols == 1:
@@ -631,7 +717,8 @@ def features_hist(data, n_rows='vertical', bins=100, xlims=None, tight=True,
 
     for ax_idx, ax in enumerate(axes.flat):
         hist_clipped(data[ax_idx], ax=ax, bins=bins, **kw['plot'])
-        _style_axis(ax, kw, show_borders, show_xy_ticks, xlims, annotations)
+        _style_axis(ax, kw, show_borders, show_xy_ticks, xlims,
+                    center_zero, annotations)
 
     if tight:
         fig.subplots_adjust(**kw['tight'])
@@ -646,7 +733,8 @@ def features_hist(data, n_rows='vertical', bins=100, xlims=None, tight=True,
 
 
 def features_hist_v2(data, colnames=None, bins=100, xlims=None, ylim=None,
-                     tight=True, side_annot=None, configs=None, **kwargs):
+                     center_zero=False, tight=True, share_xy=('col', 1),
+                     side_annot=None, configs=None, **kwargs):
     """Plots histograms in a subplot grid; tailored for multiple histograms
     per gridcell.
 
@@ -662,9 +750,19 @@ def features_hist_v2(data, colnames=None, bins=100, xlims=None, ylim=None,
         colnames: str list. Column titles, displayed on top subplot boxes.
         bins: int. Pyplot kwarg to plt.hist(), # of bins.
         xlims: float tuple. x limits to apply to all subplots.
+        center_zero: bool. If True, symmetrize xlims: (-max, max).
+              Overrides `xlims`.
         ylim: float. Top y limit of all subplots.
         tight: bool. If True, plt.subplots_adjust (spacing) according to
               configs['tight'], defaulted to minimize intermediate padding.
+        share_xy: bool/str/(tuple/list of bool/str) for (sharex, sharey)
+              kwargs passed to plt.subplots(). If bool/str, will use same
+              value for sharex & sharey.
+              - sharex: bool/str. True  -> subplots will share x-axes limits.
+                                  'col' -> limits shared along columns.
+                                  'row' -> limits shared along rows.
+                                  Overrides 'sharex' in `configs['subplot']`.
+              - sharey: bool/str. `sharex`, but for y-axis.
         side_annot: str. Text to display to the right side of rightmost subplot
               boxes, enumerated by row number ({side_annot}{row})
         configs: dict. kwargs to customize various plot schemes:
@@ -701,10 +799,22 @@ def features_hist_v2(data, colnames=None, bins=100, xlims=None, ylim=None,
     borderwidth   = kwargs.get('borderwidth', None)
     savepath      = kwargs.get('savepath', None)
 
-    def _process_configs(configs, w, h):
+    def _process_configs(configs, w, h, share_xy):
+        def _set_share_xy(kw, share_xy):
+            if isinstance(share_xy, (list, tuple)):
+                sharex, sharey = share_xy
+            else:
+                sharex = sharey = share_xy
+            if isinstance(sharex, int):
+                sharex = bool(sharex)
+            if isinstance(sharey, int):
+                sharey = bool(sharey)
+            kw['subplot']['sharex'] = sharex
+            kw['subplot']['sharey'] = sharey
+
         defaults = {
             'plot':    dict(peaks_to_clip=0),
-            'subplot': dict(sharex='col', sharey=True, dpi=76, figsize=(10, 10)),
+            'subplot': dict(dpi=76, figsize=(10, 10)),
             'title':   dict(weight='bold', fontsize=15, y=1.06),
             'tight':   dict(left=0, right=1, bottom=0, top=1,
                             wspace=.05, hspace=.05),
@@ -714,11 +824,16 @@ def features_hist_v2(data, colnames=None, bins=100, xlims=None, ylim=None,
             'save': dict(),
             }
         configs = configs or {}
+        for key in configs:
+            if key not in defaults:
+                raise ValueError(f"unexpected `configs` key: {key}; "
+                                 "supported are: %s" % ', '.join(list(defaults)))
         # override defaults, but keep those not in `configs`
         for key in defaults:
             defaults[key].update(configs.get(key, {}))
         kw = defaults.copy()
 
+        _set_share_xy(kw, share_xy)
         size = kw['subplot']['figsize']
         kw['subplot']['figsize'] = (size[0] * w, size[1] * h)
         return kw
@@ -740,7 +855,7 @@ def features_hist_v2(data, colnames=None, bins=100, xlims=None, ylim=None,
                 "number of elements")
         return n_rows, n_cols
 
-    def _style_axis(ax, kw, show_borders, show_xy_ticks, xlims):
+    def _style_axis(ax, kw, show_borders, show_xy_ticks, xlims, center_zero):
         if row == 0 and colnames is not None:
             ax.set_title(f"{colnames[col]}", **kw['colnames'])
         if side_annot is not None and col == n_cols - 1:
@@ -751,12 +866,17 @@ def features_hist_v2(data, colnames=None, bins=100, xlims=None, ylim=None,
             ax.set_xticks([])
         if not show_xy_ticks[1]:
             ax.set_yticks([])
-        if xlims is not None:
+        if center_zero:
+            maxlim = max(np.abs(ax.get_xlim()))
+            ax.set_xlim(-maxlim, maxlim)
+        elif xlims is not None:
             ax.set_xlim(*xlims)
 
     _catch_unknown_kwargs(kwargs)
-    kw = _process_configs(configs, w, h)
+    kw = _process_configs(configs, w, h, share_xy)
     n_rows, n_cols = _get_data_info(data)
+    if center_zero and xlims is not None:
+        print(NOTE, "`center_zero` will override `xlims`")
 
     fig, axes = plt.subplots(n_rows, n_cols, **kw['subplot'])
     if n_cols == 1:
@@ -772,7 +892,7 @@ def features_hist_v2(data, colnames=None, bins=100, xlims=None, ylim=None,
             for subdata in data[row][col]:
                 hist_clipped(subdata, ax=ax, bins=bins, **kw['plot'])
 
-            _style_axis(ax, kw, show_borders, show_xy_ticks, xlims)
+            _style_axis(ax, kw, show_borders, show_xy_ticks, xlims, center_zero)
 
     if ylim is not None:
         ax.set_ylim(0, ylim)
